# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sml_exporter']

package_data = \
{'': ['*']}

install_requires = \
['click>=8,<9', 'prometheus-client>=0,<1', 'pysml>=0.0.7,<0.0.8']

entry_points = \
{'console_scripts': ['sml-exporter = sml_exporter.__main__:main']}

setup_kwargs = {
    'name': 'sml-exporter',
    'version': '0.1.4',
    'description': 'Smartmeter Message Language Prometheus Exporter',
    'long_description': '# sml-exporter\n\n[Prometheus](https://prometheus.io/) Exporter for smart meters that communicate using the [SML language](https://de.wikipedia.org/wiki/Smart_Message_Language), which is widely available through read-only interfaces on smart power meters in Germany.\n\nBuilt on top of [pysml](https://github.com/mtdcr/pysml), which does most of the heavy lifting, by parsing the message stream into python objects.\n\n## Install\n\nThe [package](https://pypi.org/project/sml-exporter/) can be installed from [PyPi](https://pypi.org). It provides an executable that should be installed automatically into your environment.\n\n```\n$ python3 -m pip install sml-exporter\n```\n\nUpdate an existing installation using\n\n```\n$ python3 -m pip install -U sml-exporter\n```\n\n## Usage\n\nThe only two options available configure the serial interface where your USB to D0 (or similiar) adapter is connected at. Setting an explicit port number is useful when you have multiple power meters.\n\n```\n❯ sml-exporter --help\nUsage: sml-exporter [OPTIONS] TTY\n\nOptions:\n  -p, --http-port INTEGER RANGE  HTTP Port for the Prometheus Exporter\n                                 [default: 9761]\n\n  --help                         Show this message and exit.\n```\n\nMake sure to use stable device symlinks provided by `/dev/serial/by-id/`, so you don\'t mixup different serial devices.\n\n```\n# ls /dev/serial/by-id/\nusb-FTDI_FT232R_USB_UART_XXXXXXXX-if00-port0\nusb-FTDI_FT232R_USB_UART_YYYYYYYY-if00-port0\n```\n\n## Metrics\n\nMetrics are identified by their [OBIS](https://de.wikipedia.org/wiki/OBIS-Kennzahlen) numbering and transformed into a the following metrics:\n\n```\n# HELP smartmeter_wirkarbeit_verbrauch_total_wh Summe Wirkarbeit Verbrauch über alle Tarife (1-0:1.8.0*255)\n# TYPE smartmeter_wirkarbeit_verbrauch_total_wh gauge\nsmartmeter_wirkarbeit_verbrauch_total_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 6.8437382e+06\n# HELP smartmeter_wirkarbeit_lieferung_total_wh Summe Wirkarbeit Lieferung über alle Tarife (1-0:2.8.0*255)\n# TYPE smartmeter_wirkarbeit_lieferung_total_wh gauge\nsmartmeter_wirkarbeit_lieferung_total_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 5.8312058e+06\n# HELP smartmeter_wirkarbeit_verbrauch_tarif1_wh Summe Wirkarbeit Verbrauch im Tarif 1 (1-0:1.8.1*255)\n# TYPE smartmeter_wirkarbeit_verbrauch_tarif1_wh gauge\nsmartmeter_wirkarbeit_verbrauch_tarif1_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 6.8437382e+06\n# HELP smartmeter_wirkarbeit_lieferung_tarif1_wh Summe Wirkarbeit Lieferung im Tarif 1 (1-0:2.8.1*255)\n# TYPE smartmeter_wirkarbeit_lieferung_tarif1_wh gauge\nsmartmeter_wirkarbeit_lieferung_tarif1_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 5.8312058e+06\n# HELP smartmeter_wirkarbeit_verbrauch_tarif2_wh Summe Wirkarbeit Verbrauch im Tarif 2 (1-0:1.8.2*255)\n# TYPE smartmeter_wirkarbeit_verbrauch_tarif2_wh gauge\nsmartmeter_wirkarbeit_verbrauch_tarif2_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 0.0\n# HELP smartmeter_wirkarbeit_lieferung_tarif2_wh Summe Wirkarbeit Lieferung im Tarif 2 (1-0:2.8.2*255)\n# TYPE smartmeter_wirkarbeit_lieferung_tarif2_wh gauge\nsmartmeter_wirkarbeit_lieferung_tarif2_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 0.0\n# HELP smartmeter_wirkleistung_w Momentane Wirkleistung (1-0:16.7.0*255)\n# TYPE smartmeter_wirkleistung_w gauge\nsmartmeter_wirkleistung_w{device="1 EMH00 XXXXXXXX",vendor="EMH"} 892.4\n# HELP smartmeter_wirkarbeit_verbrauch_total_wh Summe Wirkarbeit Verbrauch über alle Tarife (1-0:1.8.0*255)\n# TYPE smartmeter_wirkarbeit_verbrauch_total_wh gauge\nsmartmeter_wirkarbeit_verbrauch_total_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 6.8437382e+06\n# HELP smartmeter_wirkarbeit_lieferung_total_wh Summe Wirkarbeit Lieferung über alle Tarife (1-0:2.8.0*255)\n# TYPE smartmeter_wirkarbeit_lieferung_total_wh gauge\nsmartmeter_wirkarbeit_lieferung_total_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 5.8312058e+06\n# HELP smartmeter_wirkarbeit_verbrauch_tarif1_wh Summe Wirkarbeit Verbrauch im Tarif 1 (1-0:1.8.1*255)\n# TYPE smartmeter_wirkarbeit_verbrauch_tarif1_wh gauge\nsmartmeter_wirkarbeit_verbrauch_tarif1_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 6.8437382e+06\n# HELP smartmeter_wirkarbeit_lieferung_tarif1_wh Summe Wirkarbeit Lieferung im Tarif 1 (1-0:2.8.1*255)\n# TYPE smartmeter_wirkarbeit_lieferung_tarif1_wh gauge\nsmartmeter_wirkarbeit_lieferung_tarif1_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 5.8312058e+06\n# HELP smartmeter_wirkarbeit_verbrauch_tarif2_wh Summe Wirkarbeit Verbrauch im Tarif 2 (1-0:1.8.2*255)\n# TYPE smartmeter_wirkarbeit_verbrauch_tarif2_wh gauge\nsmartmeter_wirkarbeit_verbrauch_tarif2_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 0.0\n# HELP smartmeter_wirkarbeit_lieferung_tarif2_wh Summe Wirkarbeit Lieferung im Tarif 2 (1-0:2.8.2*255)\n# TYPE smartmeter_wirkarbeit_lieferung_tarif2_wh gauge\nsmartmeter_wirkarbeit_lieferung_tarif2_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 0.0\n# HELP smartmeter_wirkleistung_w Momentane Wirkleistung (1-0:16.7.0*255)\n# TYPE smartmeter_wirkleistung_w gauge\nsmartmeter_wirkleistung_w{device="1 EMH00 XXXXXXXX",vendor="EMH"} 892.4# HELP smartmeter_wirkarbeit_verbrauch_total_wh Summe Wirkarbeit Verbrauch über alle Tarife (1-0:1.8.0*255)\n# TYPE smartmeter_wirkarbeit_verbrauch_total_wh gauge\nsmartmeter_wirkarbeit_verbrauch_total_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 6.8437382e+06\n# HELP smartmeter_wirkarbeit_lieferung_total_wh Summe Wirkarbeit Lieferung über alle Tarife (1-0:2.8.0*255)\n# TYPE smartmeter_wirkarbeit_lieferung_total_wh gauge\nsmartmeter_wirkarbeit_lieferung_total_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 5.8312058e+06\n# HELP smartmeter_wirkarbeit_verbrauch_tarif1_wh Summe Wirkarbeit Verbrauch im Tarif 1 (1-0:1.8.1*255)\n# TYPE smartmeter_wirkarbeit_verbrauch_tarif1_wh gauge\nsmartmeter_wirkarbeit_verbrauch_tarif1_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 6.8437382e+06\n# HELP smartmeter_wirkarbeit_lieferung_tarif1_wh Summe Wirkarbeit Lieferung im Tarif 1 (1-0:2.8.1*255)\n# TYPE smartmeter_wirkarbeit_lieferung_tarif1_wh gauge\nsmartmeter_wirkarbeit_lieferung_tarif1_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 5.8312058e+06\n# HELP smartmeter_wirkarbeit_verbrauch_tarif2_wh Summe Wirkarbeit Verbrauch im Tarif 2 (1-0:1.8.2*255)\n# TYPE smartmeter_wirkarbeit_verbrauch_tarif2_wh gauge\nsmartmeter_wirkarbeit_verbrauch_tarif2_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 0.0\n# HELP smartmeter_wirkarbeit_lieferung_tarif2_wh Summe Wirkarbeit Lieferung im Tarif 2 (1-0:2.8.2*255)\n# TYPE smartmeter_wirkarbeit_lieferung_tarif2_wh gauge\nsmartmeter_wirkarbeit_lieferung_tarif2_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 0.0\n# HELP smartmeter_wirkleistung_w Momentane Wirkleistung (1-0:16.7.0*255)\n# TYPE smartmeter_wirkleistung_w gauge\nsmartmeter_wirkleistung_w{device="1 EMH00 XXXXXXXX",vendor="EMH"} 892.4# HELP smartmeter_wirkarbeit_verbrauch_total_wh Summe Wirkarbeit Verbrauch über alle Tarife (1-0:1.8.0*255)\n# TYPE smartmeter_wirkarbeit_verbrauch_total_wh gauge\nsmartmeter_wirkarbeit_verbrauch_total_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 6.8437382e+06\n# HELP smartmeter_wirkarbeit_lieferung_total_wh Summe Wirkarbeit Lieferung über alle Tarife (1-0:2.8.0*255)\n# TYPE smartmeter_wirkarbeit_lieferung_total_wh gauge\nsmartmeter_wirkarbeit_lieferung_total_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 5.8312058e+06\n# HELP smartmeter_wirkarbeit_verbrauch_tarif1_wh Summe Wirkarbeit Verbrauch im Tarif 1 (1-0:1.8.1*255)\n# TYPE smartmeter_wirkarbeit_verbrauch_tarif1_wh gauge\nsmartmeter_wirkarbeit_verbrauch_tarif1_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 6.8437382e+06\n# HELP smartmeter_wirkarbeit_lieferung_tarif1_wh Summe Wirkarbeit Lieferung im Tarif 1 (1-0:2.8.1*255)\n# TYPE smartmeter_wirkarbeit_lieferung_tarif1_wh gauge\nsmartmeter_wirkarbeit_lieferung_tarif1_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 5.8312058e+06\n# HELP smartmeter_wirkarbeit_verbrauch_tarif2_wh Summe Wirkarbeit Verbrauch im Tarif 2 (1-0:1.8.2*255)\n# TYPE smartmeter_wirkarbeit_verbrauch_tarif2_wh gauge\nsmartmeter_wirkarbeit_verbrauch_tarif2_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 0.0\n# HELP smartmeter_wirkarbeit_lieferung_tarif2_wh Summe Wirkarbeit Lieferung im Tarif 2 (1-0:2.8.2*255)\n# TYPE smartmeter_wirkarbeit_lieferung_tarif2_wh gauge\nsmartmeter_wirkarbeit_lieferung_tarif2_wh{device="1 EMH00 XXXXXXXX",vendor="EMH"} 0.0\n# HELP smartmeter_wirkleistung_w Momentane Wirkleistung (1-0:16.7.0*255)\n# TYPE smartmeter_wirkleistung_w gauge\nsmartmeter_wirkleistung_w{device="1 EMH00 XXXXXXXX",vendor="EMH"} 892.4\n```\n\n## Caveats\n\nThe exporter caches new values as they arrive, until they are overwritten by newer ones. This design was chosen as the arrival of data usually does not match up with any particular polling interval.\nIn an ideal world we would migrate this exporter to reuse [pushgateway](https://github.com/prometheus/pushgateway). This did not happen because I don\'t have any experience using it.\n\n## License\n\nThis software is provided under the [MIT license](LICENSE) and uses\n  - [pysml](https://pypi.org/project/pysml/) MIT\n  - [click](https://pypi.org/project/click/) BSD3\n  - [prometheus-client](https://pypi.org/project/prometheus-client/) ASL20\n',
    'author': 'Martin Weinelt',
    'author_email': 'hexa@darmstadt.ccc.de',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/mweinelt/sml-exporter',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
